@@ -19,30 +19,38 @@ class Worker(object):
     _started = False
     _sleep_sec = 1.
 
-    def init(self, config_dict, connection=None, schema=None, keep_connection=False):
+    def init(self, config_dict=None, connection=None, schema=None, keep_connection=False):
         func_name = f'{self.__class__.__name__}.{sys._getframe().f_code.co_name}()'
         try:
-            if not isinstance(config_dict, dict):
-                print(f'Error in {func_name}: not isinstance(database_dict, dict)...')
-                return False
-            database_dict = config_dict.get('database')
-            if not isinstance(database_dict, dict):
-                print(f'Error in {func_name}: not isinstance(database_dict, dict)...')
+            if config_dict is None and connection is None:
+                print(f'Error in {func_name}: config_dict is None and connection is None; return...')
                 return False
+            auto_disconnect = not keep_connection
+            if connection is not None:
+                if schema is None:
+                    print(f'Error in {func_name}: connection is not None and schema is None; return...')
+                    return False
+                auto_disconnect = False
+            database_dict = None
+            if isinstance(config_dict, dict):
+                database_dict = config_dict.get('database')
+                if not isinstance(database_dict, dict):
+                    print(f'Error in {func_name}: not isinstance(database_dict, dict)...')
+                    return False
+                worker_cfg = config_dict.get('worker')
+                if isinstance(worker_cfg, dict):
+                    self._timeout_sec = float(worker_cfg.get('timeout_sec', self._timeout_sec))
+                    self._sleep_sec = float(worker_cfg.get('sleep_sec', self._sleep_sec))
             kwargs = {'settings': database_dict,
                       'connection': connection,
                       'schema': schema,
-                      'auto_disconnect': False if (connection or keep_connection) else True}
+                      'auto_disconnect': auto_disconnect}
             if not database.init(**kwargs):
                 print(f'Error in {func_name}: not database.init(); return...')
                 return False
             if not database.test_tables(create=False):
                 print(f'Error in {func_name}: not database.test_tables(); return...')
                 return False
-            worker_cfg = config_dict.get('worker')
-            if isinstance(worker_cfg, dict):
-                self._timeout_sec = float(worker_cfg.get('timeout_sec', self._timeout_sec))
-                self._sleep_sec = float(worker_cfg.get('sleep_sec', self._sleep_sec))
             return True
         except Exception as e:
             print(f'Error in {func_name}: {type(e)}: {str(e)}; traceback: {traceback.print_exc()}')
